@@ -19,6 +19,7 @@ class CmapParams:
     cmap: Colormap
     norm: Normalize
     na_color: str | tuple[float, ...] = (0.0, 0.0, 0.0, 0.0)
+    is_default: bool = True
 
 
 @dataclass
@@ -70,15 +71,16 @@ class ShapesRenderParams:
     cmap_params: CmapParams
     outline_params: OutlineParams
     elements: str | Sequence[str] | None = None
-    color: str | None = None
-    groups: str | Sequence[str] | None = None
+    color: list[str | None] | str | None = None
+    col_for_color: str | None = None
+    groups: str | list[list[str | None]] | list[str | None] | None = None
     contour_px: int | None = None
-    layer: str | None = None
-    palette: ListedColormap | str | None = None
+    palette: ListedColormap | list[list[str | None]] | list[str | None] | None = None
     outline_alpha: float = 1.0
     fill_alpha: float = 0.3
     scale: float = 1.0
     transfunc: Callable[[float], float] | None = None
+    element_table_mapping: dict[str, set[str | None] | str | None] | str | list[str] | None = None
 
 
 @dataclass
@@ -86,13 +88,15 @@ class PointsRenderParams:
     """Points render parameters.."""
 
     cmap_params: CmapParams
-    elements: str | Sequence[str] | None = None
-    color: str | None = None
-    groups: str | Sequence[str] | None = None
-    palette: ListedColormap | str | None = None
+    elements: str | list[str] | None = None
+    color: list[str | None] | str | None = None
+    col_for_color: list[str | None] | str | None = None
+    groups: str | list[list[str | None]] | list[str | None] | None = None
+    palette: ListedColormap | list[list[str | None]] | list[str | None] | None = None
     alpha: float = 1.0
     size: float = 1.0
     transfunc: Callable[[float], float] | None = None
+    element_table_mapping: dict[str, set[str | None] | str | None] | str | list[str] | None = None
 
 
 @dataclass
@@ -102,9 +106,10 @@ class ImageRenderParams:
     cmap_params: list[CmapParams] | CmapParams
     elements: str | Sequence[str] | None = None
     channel: list[str] | list[int] | int | str | None = None
-    palette: ListedColormap | str | None = None
+    palette: ListedColormap | list[list[str | None]] | list[str | None] | None = None
     alpha: float = 1.0
     quantiles_for_norm: tuple[float | None, float | None] = (None, None)
+    scale: str | list[str] | None = None
 
 
 @dataclass
@@ -113,12 +118,13 @@ class LabelsRenderParams:
 
     cmap_params: CmapParams
     elements: str | Sequence[str] | None = None
-    color: str | None = None
-    groups: str | Sequence[str] | None = None
+    color: list[str | None] | str | None = None
+    groups: str | list[list[str | None]] | list[str | None] | None = None
     contour_px: int | None = None
     outline: bool = False
-    layer: str | None = None
-    palette: ListedColormap | str | None = None
+    palette: ListedColormap | list[list[str | None]] | list[str | None] | None = None
     outline_alpha: float = 1.0
     fill_alpha: float = 0.4
     transfunc: Callable[[float], float] | None = None
+    scale: str | list[str] | None = None
+    element_table_mapping: dict[str, set[str | None] | str | None] | str | list[str] | None = None
