@@ -32,6 +32,11 @@ class TestPoints(PlotTester, metaclass=PlotTesterMeta):
         sdata_blobs["table"].uns["spatialdata_attrs"]["region"] = "blobs_points"
         sdata_blobs.pl.render_points(color="genes", groups="gene_b", palette="orange").pl.show()
 
+    def test_plot_can_filter_with_groups_default_palette(self, sdata_blobs: SpatialData):
+        sdata_blobs["table"].obs["region"] = ["blobs_points"] * sdata_blobs["table"].n_obs
+        sdata_blobs["table"].uns["spatialdata_attrs"]["region"] = "blobs_points"
+        sdata_blobs.pl.render_points(color="genes", groups="gene_b").pl.show()
+
     def test_plot_coloring_with_palette(self, sdata_blobs: SpatialData):
         sdata_blobs["table"].obs["region"] = ["blobs_points"] * sdata_blobs["table"].n_obs
         sdata_blobs["table"].uns["spatialdata_attrs"]["region"] = "blobs_points"
